##  Executing Transformations in Bulk
You can execute transformation items in bulk by switching to the table view mode in the initiative fact sheet.
To execute transformation items in bulk, do the following:
  1. In the Transformations tab of the initiative fact sheet, switch to table view mode by selecting the table icon next to the Collapse all button.
  2. By default, transformations of only one type are listed in the table. From the drop-down menu above the table, choose and change the type of transformations to be listed.
  3. Click and drag to select one or more transformation items to execute. The Review and Execute button becomes active once you have selected transformation items that are ready to be executed. You can find the indication of whether a transformation has already been executed in the Status column.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio762cbca2017d43d192a2465b3f51b0b0_HiRes.png)
Executing Transformations in Bulk
  4. In the conformation dialog, click Execute Now.
